@@ -11,6 +11,7 @@ from io import BytesIO
 from typing import Generator, Optional
 
 import pandas as pd
+from fsspec.implementations.tar import TarFileSystem
 
 from wetterdienst.exceptions import FailedDownload
 from wetterdienst.metadata.extension import Extension
@@ -129,9 +130,7 @@ def collect_radar_data(
             results = []
             for period in period_types:
 
-                file_index = create_fileindex_radolan_cdc(
-                    resolution=resolution, period=period
-                )
+                file_index = create_fileindex_radolan_cdc(resolution=resolution, period=period)
 
                 # Filter for dates range if start_date and end_date are defined.
                 if period == Period.RECENT:
@@ -143,14 +142,8 @@ def collect_radar_data(
                 # This is for matching historical data, e.g. "RW-200509.tar.gz".
                 else:
                     file_index = file_index[
-                        (
-                            file_index[DwdColumns.DATETIME.value].dt.year
-                            == start_date.year
-                        )
-                        & (
-                            file_index[DwdColumns.DATETIME.value].dt.month
-                            == start_date.month
-                        )
+                        (file_index[DwdColumns.DATETIME.value].dt.year == start_date.year)
+                        & (file_index[DwdColumns.DATETIME.value].dt.month == start_date.month)
                     ]
 
                 results.append(file_index)
@@ -219,15 +212,14 @@ def collect_radar_data(
                     log.exception("Unable to read HDF5 file")
 
 
-def should_cache_download(url) -> bool:  # pragma: no cover
+def should_cache_download(url: str) -> bool:  # pragma: no cover
     """
     Determine whether this specific result should be cached.
 
     Here, we don't want to cache any files containing "-latest-" in their filenames.
 
-    :param args: Arguments of decorated function.
-    :param kwargs: Keyword arguments of decorated function.
-    :return: When cache should be dimissed, return False. Otherwise, return True.
+    :param url: url string which is used to decide if result is cached
+    :return: When cache should be dismissed, return False. Otherwise, return True.
     """
     if "-latest-" in url:
         return False
@@ -250,20 +242,17 @@ def _download_generic_data(url: str) -> Generator[RadarResult, None, None]:
 
     data = download_file(url, ttl=ttl)
 
-    data.seek(0)
-
     # RadarParameter.FX_REFLECTIVITY
     if url.endswith(Extension.TAR_BZ2.value):
-        with bz2.BZ2File(data, mode="rb") as archive:
-            with tarfile.open(fileobj=archive) as tar_file:
-                for file in tar_file.getmembers():
-                    yield RadarResult(
-                        data=BytesIO(tar_file.extractfile(file).read()),
-                        timestamp=get_date_from_filename(file.name),
-                        filename=file.name,
-                    )
+        tfs = TarFileSystem(data, compression="bz2")
+        for file in tfs.glob("*"):
+            yield RadarResult(
+                data=tfs.open(file).read(),
+                timestamp=get_date_from_filename(file.name),
+                filename=file.name,
+            )
 
-    # RadarParameter.WN_REFLECTIVITY, RADAR_PARAMETERS_SWEEPS (BUFR)
+    # RadarParameter.WN_REFLECTIVITY, RADAR_PARAMETERS_SWEEPS (BUFR)  # noqa: E800
     elif url.endswith(Extension.BZ2.value):
         with bz2.BZ2File(data, mode="rb") as archive:
             data = BytesIO(archive.read())
@@ -321,9 +310,7 @@ def _download_radolan_data(remote_radolan_filepath: str) -> BytesIO:
     return download_file(remote_radolan_filepath, ttl=CacheExpiry.TWELVE_HOURS)
 
 
-def _extract_radolan_data(
-    date_time: datetime, archive_in_bytes: BytesIO
-) -> RadarResult:
+def _extract_radolan_data(date_time: datetime, archive_in_bytes: BytesIO) -> RadarResult:
     """
     Function used to extract RADOLAN_CDC file for the requested datetime
     from the downloaded archive.
@@ -344,26 +331,20 @@ def _extract_radolan_data(
         # Have to seek(0) as the archive might be reused
         archive_in_bytes.seek(0)
 
-        with gzip.GzipFile(fileobj=archive_in_bytes, mode="rb") as gz_file:
-            file_in_archive = BytesIO(gz_file.read())
+        tfs = TarFileSystem(archive_in_bytes, compression="gzip")
+        file = tfs.glob(f"*{date_time_string}*")
 
-            with tarfile.open(fileobj=file_in_archive) as tar_file:
-                for file in tar_file.getmembers():
-                    if date_time_string in file.name:
-                        return RadarResult(
-                            data=BytesIO(tar_file.extractfile(file).read()),
-                            timestamp=date_time,
-                            filename=file.name,
-                        )
+        if len(file) != 1:
+            raise FileNotFoundError(f"RADOLAN file for {date_time_string} not found.")  # pragma: no cover
 
-                raise FileNotFoundError(
-                    f"RADOLAN file for {date_time_string} not found."
-                )  # pragma: no cover
+        return RadarResult(
+            data=BytesIO(tfs.open(file[0]).read()),
+            timestamp=date_time,
+            filename=file,
+        )
 
     except EOFError as ex:
-        raise FailedDownload(
-            f"RADOLAN file for {date_time_string} is invalid: {ex}"
-        )  # pragma: no cover
+        raise FailedDownload(f"RADOLAN file for {date_time_string} is invalid: {ex}")  # pragma: no cover
 
     # Otherwise if there's an error the data is from recent time period and only has to
     # be unpacked once
@@ -372,6 +353,4 @@ def _extract_radolan_data(
         archive_in_bytes.seek(0)
 
         with gzip.GzipFile(fileobj=archive_in_bytes, mode="rb") as gz_file:
-            return RadarResult(
-                data=BytesIO(gz_file.read()), timestamp=date_time, filename=gz_file.name
-            )
+            return RadarResult(data=BytesIO(gz_file.read()), timestamp=date_time, filename=gz_file.name)
