@@ -86,7 +86,7 @@ def dashboard_layout() -> html:
                     html.Div(
                         [
                             html.Div(
-                                id="status-response-stations",
+                                id="status-response-stations_result",
                             ),
                             html.Hr(),
                             html.Div(
@@ -97,7 +97,7 @@ def dashboard_layout() -> html:
                         className="col wd-panel flex-column",
                     ),
                     html.Div(
-                        [dcc.Graph(id="map-stations")],
+                        [dcc.Graph(id="map-stations_result")],
                         id="map",
                         className="col wd-panel",
                     ),
@@ -117,6 +117,6 @@ def dashboard_layout() -> html:
                 ],
                 className="d-flex flex-row",
             ),
-            html.Div([], id="dataframe-stations", style={"display": "None"}),
+            html.Div([], id="dataframe-stations_result", style={"display": "None"}),
         ],
     )
